pygeodesy.cartesianBase.CartesianBase

Package pygeodesy :: Module cartesianBase :: Class CartesianBase |
[frames] | no frames]

# Class CartesianBase

           object --+
                    |
         named._Named --+
                        |
         named._NamedBase --+
                            |
    vector3dBase.Vector3dBase --+
                                |
                vector3d.Vector3d --+
                                    |
                   object --+       |
                            |       |
                 named._Named --+   |
                                |   |
            ecefLocals._EcefLocal --+
                                    |
                                   CartesianBase

Known Subclasses:
  - ellipsoidalBase.CartesianEllipsoidalBase
  - , sphericalBase.CartesianSphericalBase

(INTERNAL) Base class for ellipsoidal and spherical `Cartesian`.

Instance Methods
Roc2(self, earth=None) Compute this cartesian's normal and pseudo, z-based radius of curvature. |
__init__(self, x_xyz, y=None, z=None, datum=None, **ll_name) New `Cartesian...`. |
cassini(self, pointB, pointC, alpha, beta, useZ=False) 3-Point resection between this and 2 other points using Cassini's method. |
collins(self, pointB, pointC, alpha, beta, useZ=False) DEPRECATED, use method collins5. |
collins5(self, pointB, pointC, alpha, beta, useZ=False) 3-Point resection between this and 2 other points using Collins' method. |
convertDatum(self, datum2, **datum) DEPRECATED, use method toDatum. |
destinationXyz(self, delta, Cartesian=None, **name_Cartesian_kwds) Calculate the destination using a local delta from this cartesian. |
hartzell(self, los=False, earth=None) Compute the intersection of a Line-Of-Sight from this cartesian Point-Of-View (pov) and this cartesian's `datum` ellipsoid surface. |
height3(self, earth=None, height=None, **Cartesian_and_kwds) Compute the cartesian at a height above or below this certesian's `datum` ellipsoid surface. |
height4(self, earth=None, normal=True, **Cartesian_and_kwds) Compute the projection of this point on and the height above or below this datum's ellipsoid surface. |
pierlot(self, point2, point3, alpha12, alpha23, useZ=False, eps=2.220446049250313e-16) 3-Point resection between this and two other points using Pierlot's method `ToTal` with approximate limits for the (pseudo-)singularities. |
pierlotx(self, point2, point3, alpha1, alpha2, alpha3, useZ=False) 3-Point resection between this and two other points using Pierlot's method `ToTal` with exact limits for the (pseudo-)singularities. |
tienstra(self, pointB, pointC, alpha, beta=None, gamma=None, useZ=False) DEPRECATED, use method tienstra7. |
tienstra7(self, pointB, pointC, alpha, beta=None, gamma=None, useZ=False) 3-Point resection between this and two other points using Tienstra's formula. |
to2ab(self) DEPRECATED, use property `philam`. |
to2ll(self) DEPRECATED, use property `latlon`. |
to3llh(self, datum=None) DEPRECATED, use property latlonheight or latlonheightdatum. |
toDatum(self, datum2, datum=None) Convert this cartesian from one datum to an other. |
toEcef(self) Convert this cartesian to geodetic (lat-/longitude) coordinates. |
toLatLon(self, datum=None, height=None, LatLon=None, **LatLon_kwds) Convert this cartesian to a geodetic (lat-/longitude) point. |
toNvector(self, Nvector=None, datum=None, **name_Nvector_kwds) Convert this cartesian to `n-vector` components, including height. |
toRtp(self) Convert this cartesian to spherical, polar coordinates. |
toStr(self, prec=3, fmt='[%s]', sep=', ') Return the string representation of this cartesian. |
toTransform(self, transform, inverse=False, datum=None) Apply a Helmert transform to this cartesian. |
toVector(self, Vector=None, **Vector_kwds) Return this cartesian's geocentric components as vector. |
Inherited from `vector3d.Vector3d`: `bearing`, `circin6`, `circum3`, `circum4_`, `iscolinearWith`, `meeus2`, `nearestOn`, `nearestOn6`, `parse`, `radii11`, `soddy4`, `toCartesian`, `trilaterate2d2`, `trilaterate3d2` Inherited from `vector3dBase.Vector3dBase`: `__abs__`, `__add__`, `__bool__`, `__ceil__`, `__cmp__`, `__div__`, `__divmod__`, `__eq__`, `__float__`, `__floor__`, `__floordiv__`, `__ge__`, `__gt__`, `__hash__`, `__iadd__`, `__idiv__`, `__ifloordiv__`, `__imatmul__`, `__imod__`, `__imul__`, `__int__`, `__ipow__`, `__isub__`, `__itruediv__`, `__le__`, `__long__`, `__lt__`, `__matmul__`, `__mod__`, `__mul__`, `__ne__`, `__neg__`, `__nonzero__`, `__pos__`, `__pow__`, `__radd__`, `__rdiv__`, `__rdivmod__`, `__rfloordiv__`, `__rmatmul__`, `__rmod__`, `__rmul__`, `__round__`, `__rpow__`, `__rsub__`, `__rtruediv__`, `__sub__`, `__truediv__`, `__trunc__`, `angleTo`, `apply`, `bools`, `cmp`, `cross`, `dividedBy`, `dividedBy_`, `dot`, `equals`, `equirectangular`, `fabs`, `floats`, `floorDividedBy`, `floorDividedBy_`, `intermediateTo`, `ints`, `isconjugateTo`, `isequalTo`, `minus`, `minus_`, `negate`, `others`, `plus`, `plus_`, `pow`, `rotate`, `rotateAround`, `sum`, `times`, `times_`, `to3xyz`, `unit` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `toRepr` Inherited from `ecefLocals._EcefLocal`: `toAer`, `toEnu`, `toLocal`, `toLtp`, `toNed`, `toXyz` Inherited from `named._Named`: `__format__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| datum Class `property` with a `.name` attribute.
| ellipsoidalCartesian Get the `Cartesian type` iff ellipsoidal, overloaded in CartesianEllipsoidalBase.
| height Get the height (`meter`).
| isEllipsoidal Check whether this cartesian is ellipsoidal (`bool` or `None` if unknown).
| isSpherical Check whether this cartesian is spherical (`bool` or `None` if unknown).
| latlon Get this cartesian's (geodetic) lat- and longitude in `degrees` (LatLon2Tuple`(lat, lon)`).
| latlonheight Get this cartesian's (geodetic) lat-, longitude in `degrees` with height (LatLon3Tuple`(lat, lon, height)`).
| latlonheightdatum Get this cartesian's (geodetic) lat-, longitude in `degrees` with height and datum (LatLon4Tuple`(lat, lon, height, datum)`).
| philam Get this cartesian's (geodetic) lat- and longitude in `radians` (PhiLam2Tuple`(phi, lam)`).
| philamheight Get this cartesian's (geodetic) lat-, longitude in `radians` with height (PhiLam3Tuple`(phi, lam, height)`).
| philamheightdatum Get this cartesian's (geodetic) lat-, longitude in `radians` with height and datum (PhiLam4Tuple`(phi, lam, height, datum)`).
| sphericalCartesian Get the `Cartesian type` iff spherical, overloaded in CartesianSphericalBase.
Inherited from `vector3dBase.Vector3dBase`: `crosserrors`, `euclid`, `homogeneous`, `length`, `length2`, `x`, `x2y2z2`, `x2y2z23`, `xyz`, `xyz3`, `y`, `z` Inherited from `ecefLocals._EcefLocal`: `Ecef` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### Roc2 (self, earth=None) |
Compute this cartesian's normal and pseudo, z-based radius of curvature. Arguments: `earth` - A datum, ellipsoid, triaxial ellipsoid or earth radius, overriding this cartesian's datum (Datum, Ellipsoid, Ellipsoid2, a_f2Tuple or `meter`, conventionally). Returns: 2-Tuple `(R, r)` with the normal and pseudo, z-based radius of curvature `R` respectively `r`, both in `meter` conventionally. Raises: `TypeError` - Invalid or undefined `earth` or `datum`.

### __init__ (self, x_xyz, y=None, z=None, datum=None, **ll_name) (Constructor) |
New `Cartesian...`. Arguments: `x_xyz` - Cartesian X coordinate (`scalar`) or a `Cartesian`, Ecef9Tuple, Vector3Tuple or Vector4Tuple. `y` - Cartesian Y coordinate (`scalar`), ignored if `x_xyz` is not `scalar`, otherwise same units as `x_xyz`. `z` - Cartesian Z coordinate (`scalar`), like `y`. `datum` - Optional datum (Datum, Ellipsoid, Ellipsoid2 or a_f2Tuple). `ll_name` - Optional `name=NN` (`str`) and optional, original latlon `ll=None` (`LatLon`). Raises: `TypeError` - Non-scalar `x_xyz`, `y` or `z` coordinate or `x_xyz` not a `Cartesian`, Ecef9Tuple, Vector3Tuple or Vector4Tuple or `datum` is not a Datum. Overrides: object.__init__

### cassini (self, pointB, pointC, alpha, beta, useZ=False) |
3-Point resection between this and 2 other points using Cassini's method. Arguments: `pointB` - Second point (`Cartesian`, Vector3d, `Vector3Tuple`, `Vector4Tuple` or `Vector2Tuple` if `useZ=False`). `pointC` - Center point (`Cartesian`, Vector3d, `Vector3Tuple`, `Vector4Tuple` or `Vector2Tuple` if `useZ=False`). `alpha` - Angle subtended by triangle side `b` from `pointA` to `pointC` (`degrees`, non-negative). `beta` - Angle subtended by triangle side `a` from `pointB` to `pointC` (`degrees`, non-negative). `useZ` - If `True`, use and interpolate the Z component, otherwise force `z=INT0` (`bool`). Returns: The survey point, an instance of this (sub-)class. Raises: `ResectionError` - Near-coincident, -colinear or -concyclic points or negative or invalid `alpha` or `beta`. `TypeError` - Invalid `pointA`, `pointB` or `pointM`. Note: Typically, `pointC` is between this and `pointB`. See Also: Function pygeodesy.cassini for references and more details.

### collins (self, pointB, pointC, alpha, beta, useZ=False) |
DEPRECATED, use method collins5. Decorators: `@deprecated_method`

### collins5 (self, pointB, pointC, alpha, beta, useZ=False) |
3-Point resection between this and 2 other points using Collins' method. Arguments: `pointB` - Second point (`Cartesian`, Vector3d, `Vector3Tuple`, `Vector4Tuple` or `Vector2Tuple` if `useZ=False`). `pointC` - Center point (`Cartesian`, Vector3d, `Vector3Tuple`, `Vector4Tuple` or `Vector2Tuple` if `useZ=False`). `alpha` - Angle subtended by triangle side `b` from `pointA` to `pointC` (`degrees`, non-negative). `beta` - Angle subtended by triangle side `a` from `pointB` to `pointC` (`degrees`, non-negative). `useZ` - If `True`, use and interpolate the Z component, otherwise force `z=INT0` (`bool`). Returns: Collins5Tuple`(pointP, pointH, a, b, c)` with survey `pointP`, auxiliary `pointH`, each an instance of this (sub-)class and triangle sides `a`, `b` and `c`. Raises: `ResectionError` - Near-coincident, -colinear or -concyclic points or negative or invalid `alpha` or `beta`. `TypeError` - Invalid `pointB` or `pointM`. Note: Typically, `pointC` is between this and `pointB`. See Also: Function pygeodesy.collins5 for references and more details.

### convertDatum (self, datum2, **datum) |
DEPRECATED, use method toDatum. Decorators: `@deprecated_method`

### destinationXyz (self, delta, Cartesian=None, **name_Cartesian_kwds) |
Calculate the destination using a local delta from this cartesian. Arguments: `delta` - Local delta to the destination (XyzLocal, Enu, Ned or Local9Tuple). `Cartesian` - Optional (geocentric) class to return the destination or `None`. `name_Cartesian_kwds` - Optional `name=NN` (`str`) and optionally, additional `Cartesian` keyword arguments, ignored if `Cartesian is None`. Returns: Destination as a `Cartesian(x, y, z, **Cartesian_kwds)` instance or if `Cartesian is None`, an Ecef9Tuple`(x, y, z, lat, lon, height, C, M, datum)` with `M=None` always. Raises: `TypeError` - Invalid `delta`, `Cartesian` or `Cartesian_kwds` item or `datum` missing or incompatible.

### hartzell (self, los=False, earth=None) |
Compute the intersection of a Line-Of-Sight from this cartesian Point-Of-View (pov) and this cartesian's `datum` ellipsoid surface. Arguments: `los` - Line-Of-Sight, direction to the ellipsoid (Los, Vector3d), `True` for the normal, plumb onto the surface or False or `None` to point to the center of the ellipsoid. `earth` - The earth model (Datum, Ellipsoid, Ellipsoid2, a_f2Tuple or `scalar` radius in `meter`), overriding this cartesian's datum. Returns: The intersection (`Cartesian`) with `.height` set to the distance to this `pov`. Raises: `IntersectionError` - Null or bad `pov` or `los`, this `pov` is inside the ellipsoid or `los` points outside or away from the ellipsoid. `TypeError` - Invalid `los` or invalid or undefined `earth` or `datum`. See Also: Function hartzell for further details.

### height3 (self, earth=None, height=None, **Cartesian_and_kwds) |
Compute the cartesian at a height above or below this certesian's `datum` ellipsoid surface. Arguments: `earth` - A datum, ellipsoid, triaxial ellipsoid or earth radius, overriding this cartesian's datum (Datum, Ellipsoid, Ellipsoid2, a_f2Tuple or `meter`, conventionally). `height` - The height (`meter`, conventionally), overriding this cartesian's height. `Cartesian_and_kwds` - Optional `Cartesian=None` class to return the cartesian at height and additional `Cartesian` keyword arguments. Returns: An instance of `Cartesian` or if `Cartesian is None`, a Vector3Tuple`(x, y, z)` with the `x`, `y` and `z` coordinates at height in `meter`, conventionally. Raises: `TypeError` - Invalid or undefined `earth` or `datum`. Notes: This cartesian's coordinates are returned if `earth` and this datum or `height` and/or this height are `None` or undefined. Include keyword argument `datum=None` if class `Cartesian` does not accept a `datum` keyword agument.

### height4 (self, earth=None, normal=True, **Cartesian_and_kwds) |
Compute the projection of this point on and the height above or below this datum's ellipsoid surface. Arguments: `earth` - A datum, ellipsoid, triaxial ellipsoid or earth radius, overriding this datum (Datum, Ellipsoid, Ellipsoid2, a_f2Tuple, Triaxial, Triaxial_, JacobiConformal or `meter`, conventionally). `normal` - If `True`, the projection is the nearest point on the ellipsoid's surface, otherwise the intersection of the radial line to the ellipsoid's center and surface `bool`). `Cartesian_and_kwds` - Optional `Cartesian=None` class to return the projection and additional `Cartesian` keyword arguments. Returns: An instance of `Cartesian` or if `Cartesian is None`, a Vector4Tuple`(x, y, z, h)` with the projection `x`, `y` and `z` coordinates and height `h` in `meter`, conventionally. Raises: `TriaxialError` - No convergence in triaxial root finding. `TypeError` - Invalid or undefined `earth` or `datum`. Note: Include keyword argument `datum=None` if class `Cartesian` does not accept a `datum` keyword agument. See Also: Methods Ellipsoid.height4 and Triaxial_.height4 for more information.

### pierlot (self, point2, point3, alpha12, alpha23, useZ=False, eps=2.220446049250313e-16) |
3-Point resection between this and two other points using Pierlot's method `ToTal` with approximate limits for the (pseudo-)singularities. Arguments: `point2` - Second point (`Cartesian`, Vector3d, `Vector3Tuple`, `Vector4Tuple` or `Vector2Tuple` if `useZ=False`). `point3` - Third point (`Cartesian`, Vector3d, `Vector3Tuple`, `Vector4Tuple` or `Vector2Tuple` if `useZ=False`). `alpha12` - Angle subtended from this point to `point2` or `alpha2 - alpha` (`degrees`). `alpha23` - Angle subtended from `point2` to `point3` or `alpha3 - alpha2` (`degrees`). `useZ` - If `True`, interpolate the Z component, otherwise use `z=INT0` (`bool`). `eps` - Tolerance for `cot` (pseudo-)singularities (`float`). Returns: The survey (or robot) point, an instance of this (sub-)class. Raises: `ResectionError` - Near-coincident, -colinear or -concyclic points or invalid `alpha12` or `alpha23`. `TypeError` - Invalid `point2` or `point3`. Note: This point, `point2` and `point3` are ordered counter-clockwise. See Also: Function pygeodesy.pierlot for references and more details.

### pierlotx (self, point2, point3, alpha1, alpha2, alpha3, useZ=False) |
3-Point resection between this and two other points using Pierlot's method `ToTal` with exact limits for the (pseudo-)singularities. Arguments: `point2` - Second point (`Cartesian`, Vector3d, `Vector3Tuple`, `Vector4Tuple` or `Vector2Tuple` if `useZ=False`). `point3` - Third point (`Cartesian`, Vector3d, `Vector3Tuple`, `Vector4Tuple` or `Vector2Tuple` if `useZ=False`). `alpha1` - Angle at `point1` (`degrees`). `alpha2` - Angle at `point2` (`degrees`). `alpha3` - Angle at `point3` (`degrees`). `useZ` - If `True`, interpolate the survey point's Z component, otherwise use `z=INT0` (`bool`). Returns: The survey (or robot) point, an instance of this (sub-)class. Raises: `ResectionError` - Near-coincident, -colinear or -concyclic points or invalid `alpha1`, `alpha2` or `alpha3`. `TypeError` - Invalid `point2` or `point3`. See Also: Function pygeodesy.pierlotx for references and more details.

### tienstra (self, pointB, pointC, alpha, beta=None, gamma=None, useZ=False) |
DEPRECATED, use method tienstra7. Decorators: `@deprecated_method`

### tienstra7 (self, pointB, pointC, alpha, beta=None, gamma=None, useZ=False) |
3-Point resection between this and two other points using Tienstra's formula. Arguments: `pointB` - Second point (`Cartesian`, Vector3d, `Vector3Tuple`, `Vector4Tuple` or `Vector2Tuple` if `useZ=False`). `pointC` - Third point (`Cartesian`, Vector3d, `Vector3Tuple`, `Vector4Tuple` or `Vector2Tuple` if `useZ=False`). `alpha` - Angle subtended by triangle side `a` from `pointB` to `pointC` (`degrees`, non-negative). `beta` - Angle subtended by triangle side `b` from this to `pointC` (`degrees`, non-negative) or `None` if `gamma is not None`. `gamma` - Angle subtended by triangle side `c` from this to `pointB` (`degrees`, non-negative) or `None` if `beta is not None`. `useZ` - If `True`, use and interpolate the Z component, otherwise force `z=INT0` (`bool`). Returns: Tienstra7Tuple`(pointP, A, B, C, a, b, c)` with survey `pointP`, an instance of this (sub-)class and triangle angle `A` at this point, `B` at `pointB` and `C` at `pointC` in `degrees` and triangle sides `a`, `b` and `c`. Raises: `ResectionError` - Near-coincident, -colinear or -concyclic points or sum of `alpha`, `beta` and `gamma` not `360` or negative `alpha`, `beta` or `gamma`. `TypeError` - Invalid `pointB` or `pointC`. Note: This point, `pointB` and `pointC` are ordered clockwise. See Also: Function pygeodesy.tienstra7 for references and more details.

### to2ab (self) |
DEPRECATED, use property `philam`. Returns: A PhiLam2Tuple`(phi, lam)`. Decorators: `@deprecated_method`

### to2ll (self) |
DEPRECATED, use property `latlon`. Returns: A LatLon2Tuple`(lat, lon)`. Decorators: `@deprecated_method`

### to3llh (self, datum=None) |
DEPRECATED, use property latlonheight or latlonheightdatum. Returns: A LatLon4Tuple`(lat, lon, height, datum)`. Decorators: `@deprecated_method` Note: This method returns a `-4Tuple` and not a `-3Tuple` as its name may suggest.

### toDatum (self, datum2, datum=None) |
Convert this cartesian from one datum to an other. Arguments: `datum2` - Datum to convert to (Datum). `datum` - Datum to convert from (Datum). Returns: The converted point (`Cartesian`). Raises: `TypeError` - `datum2` or `datum` invalid.

### toEcef (self) |
Convert this cartesian to geodetic (lat-/longitude) coordinates. Returns: An Ecef9Tuple`(x, y, z, lat, lon, height, C, M, datum)` with `C` and `M` if available. Raises: `EcefError` - A `.datum` or an ECEF issue.

### toLatLon (self, datum=None, height=None, LatLon=None, **LatLon_kwds) |
Convert this cartesian to a geodetic (lat-/longitude) point. Arguments: `datum` - Optional datum (Datum, Ellipsoid, Ellipsoid2 or a_f2Tuple). `height` - Optional height, overriding the converted height (`meter`), only if `LatLon is not None`. `LatLon` - Optional class to return the geodetic point (`LatLon`) or `None`. `LatLon_kwds` - Optional, additional `LatLon` keyword arguments, ignored if `LatLon is None`. Returns: The geodetic point (`LatLon`) or if `LatLonis None`, an Ecef9Tuple`(x, y, z, lat, lon, height, C, M, datum)` with `C` and `M` if available. Raises: `TypeError` - Invalid `datum` or `LatLon_kwds`.

### toNvector (self, Nvector=None, datum=None, **name_Nvector_kwds) |
Convert this cartesian to `n-vector` components, including height. Arguments: `Nvector` - Optional class to return the `n-vector` components (`Nvector`) or `None`. `datum` - Optional datum (Datum, Ellipsoid, Ellipsoid2 or a_f2Tuple) overriding this cartesian's datum. `name_Nvector_kwds` - Optional `name=NN` (`str`) and optionally, additional `Nvector` keyword arguments, ignored if `Nvector is None`. Returns: An `Nvector` or a Vector4Tuple`(x, y, z, h)` if `Nvector is None`. Raises: `TypeError` - Invalid `Nvector`, `datum` or `name_Nvector_kwds` item. `ValueError` - `Cartesian` at origin.

### toRtp (self) |
Convert this cartesian to spherical, polar coordinates. Returns: RadiusThetaPhi3Tuple`(r, theta, phi)` with `theta` and `phi`, both in Degrees. See Also: Function xyz2rtp_ and class RadiusThetaPhi3Tuple.

### toStr (self, prec=3, fmt='[%s]', sep=', ') |
Return the string representation of this cartesian. Arguments: `prec` - Number of (decimal) digits, unstripped (`int`). `fmt` - Enclosing backets format (`letter`). `sep` - Separator to join (`str`). Returns: Cartesian represented as "[x, y, z]" (`str`). Overrides: named._Named.toStr

### toTransform (self, transform, inverse=False, datum=None) |
Apply a Helmert transform to this cartesian. Arguments: `transform` - Transform to apply (Transform or TransformXform). `inverse` - Apply the inverse of the `transform` (`bool`). `datum` - Datum for the transformed cartesian (Datum), overriding this cartesian's datum but not taken it into account. Returns: A transformed cartesian (`Cartesian`) or a copy of this cartesian if `transform.isunity`. Raises: `TypeError` - Invalid `transform`.

### toVector (self, Vector=None, **Vector_kwds) |
Return this cartesian's geocentric components as vector. Arguments: `Vector` - Optional class to return the geocentric components (Vector3d) or `None`. `Vector_kwds` - Optional, additional `Vector` keyword arguments, ignored if `Vector is None`. Returns: A `Vector` or a Vector3Tuple`(x, y, z)` if `Vector is None`. Raises: `TypeError` - Invalid `Vector` or `Vector_kwds`.

Property Details

### datum Class `property` with a `.name` attribute. Get method: datum(self) - Get this cartesian's datum (Datum). Set method: datum(self, datum) - Set this cartesian's `datum` without conversion (Datum), ellipsoidal or spherical.

### ellipsoidalCartesian Get the `Cartesian type` iff ellipsoidal, overloaded in CartesianEllipsoidalBase. Get method: ellipsoidalCartesian(self) - Get the `Cartesian type` iff ellipsoidal, overloaded in CartesianEllipsoidalBase. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### height Get the height (`meter`). Get method: height(self) - Get the height (`meter`). Set method: height(self, height) - Set the height (`meter`). Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isEllipsoidal Check whether this cartesian is ellipsoidal (`bool` or `None` if unknown). Get method: isEllipsoidal(self) - Check whether this cartesian is ellipsoidal (`bool` or `None` if unknown). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isSpherical Check whether this cartesian is spherical (`bool` or `None` if unknown). Get method: isSpherical(self) - Check whether this cartesian is spherical (`bool` or `None` if unknown). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### latlon Get this cartesian's (geodetic) lat- and longitude in `degrees` (LatLon2Tuple`(lat, lon)`). Get method: latlon(self) - Get this cartesian's (geodetic) lat- and longitude in `degrees` (LatLon2Tuple`(lat, lon)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### latlonheight Get this cartesian's (geodetic) lat-, longitude in `degrees` with height (LatLon3Tuple`(lat, lon, height)`). Get method: latlonheight(self) - Get this cartesian's (geodetic) lat-, longitude in `degrees` with height (LatLon3Tuple`(lat, lon, height)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### latlonheightdatum Get this cartesian's (geodetic) lat-, longitude in `degrees` with height and datum (LatLon4Tuple`(lat, lon, height, datum)`). Get method: latlonheightdatum(self) - Get this cartesian's (geodetic) lat-, longitude in `degrees` with height and datum (LatLon4Tuple`(lat, lon, height, datum)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### philam Get this cartesian's (geodetic) lat- and longitude in `radians` (PhiLam2Tuple`(phi, lam)`). Get method: philam(self) - Get this cartesian's (geodetic) lat- and longitude in `radians` (PhiLam2Tuple`(phi, lam)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### philamheight Get this cartesian's (geodetic) lat-, longitude in `radians` with height (PhiLam3Tuple`(phi, lam, height)`). Get method: philamheight(self) - Get this cartesian's (geodetic) lat-, longitude in `radians` with height (PhiLam3Tuple`(phi, lam, height)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### philamheightdatum Get this cartesian's (geodetic) lat-, longitude in `radians` with height and datum (PhiLam4Tuple`(phi, lam, height, datum)`). Get method: philamheightdatum(self) - Get this cartesian's (geodetic) lat-, longitude in `radians` with height and datum (PhiLam4Tuple`(phi, lam, height, datum)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### sphericalCartesian Get the `Cartesian type` iff spherical, overloaded in CartesianSphericalBase. Get method: sphericalCartesian(self) - Get the `Cartesian type` iff spherical, overloaded in CartesianSphericalBase. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.